.wp-block-query__enhanced-pagination-animation{
  background-color:var(--wp--preset--color--primary, #000);
  height:4px;
  margin:0;
  max-width:100vw !important;
  opacity:0;
  padding:0;
  position:fixed;
  right:0;
  top:0;
  width:100vw;
}
.wp-block-query__enhanced-pagination-animation.start-animation{
  animation:wp-block-query__enhanced-pagination-start-animation 30s cubic-bezier(.03, .5, 0, 1) forwards;
}
.wp-block-query__enhanced-pagination-animation.finish-animation{
  animation:wp-block-query__enhanced-pagination-finish-animation .3s ease-in;
}

@keyframes wp-block-query__enhanced-pagination-start-animation{
  0%{
    opacity:1;
    transform:scaleX(0);
    transform-origin:100% 0;
  }
  to{
    opacity:1;
    transform:scaleX(1);
    transform-origin:100% 0;
  }
}
@keyframes wp-block-query__enhanced-pagination-finish-animation{
  0%{
    opacity:1;
  }
  50%{
    opacity:1;
  }
  to{
    opacity:0;
  }
}